@@ -9,6 +9,7 @@ from . import (base,
                properties,
                exceptions,
                functional,
+               units_of_measure,
 )
 from ._chemical import Chemical
 from ._chemicals import Chemicals, CompiledChemicals
@@ -29,7 +30,8 @@ from flexsolve import speed_up
 __all__ = ('Chemical', 'Chemicals', 'CompiledChemicals', 'Thermo', 'indexer',
            'Stream', 'MultiStream', 'ThermalCondition', 'mixture', 'ThermoData',
            'settings', 'functor', 'properties', 'base', 'equilibrium',
-           'exceptions', 'functional', 'reaction', 'utils', 'speed_up')
+           'units_of_measure', 'exceptions', 'functional', 'reaction',
+           'utils', 'speed_up')
 
 # Set number of digits displayed
 import numpy as np
