@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 import thermosteam as tmo
 from flexsolve import IQ_interpolation
-from .utils import copy_maybe, to_searchable_format
-from .properties.identifiers import CAS_from_any, pubchem_db
+from .utils import copy_maybe
+from .properties.identifiers import chemical_metadata_from_any, pubchem_db
 from .properties.vapor_pressure import vapor_pressure_handle
 from .properties.phase_change import (normal_boiling_point_temperature,
                                       normal_melting_point_temperature,
@@ -35,17 +35,17 @@ from .properties.free_energy import (
 from .base import (PhaseHandle, PhaseTHandle, PhaseTPHandle,
                    ThermoModelHandle, TDependentModelHandle,
                    TPDependentModelHandle, display_asfunctor)
-from .base.units_of_measure import chemical_units_of_measure
+from .units_of_measure import chemical_units_of_measure
 from .properties.dipole import dipole_moment
 from . import functional as fn 
 from .properties.permittivity import permitivity_handle
 from .properties.interface import surface_tension_handle
-from .equilibrium.unifac_data import (DDBST_UNIFAC_assignments, 
-                                      DDBST_MODIFIED_UNIFAC_assignments,
-                                      DDBST_PSRK_assignments,
-                                      UNIFACGroupCounts, 
-                                      DortmundGroupCounts, 
-                                      PSRKGroupCounts)
+from .properties.unifac import (DDBST_UNIFAC_assignments, 
+                                DDBST_MODIFIED_UNIFAC_assignments,
+                                DDBST_PSRK_assignments,
+                                UNIFACGroupCounts, 
+                                DortmundGroupCounts, 
+                                PSRKGroupCounts)
 from .exceptions import DomainError
 # from .solubility import SolubilityParameter
 # from .lennard_jones import Stockmayer, MolecularDiameter
@@ -518,13 +518,10 @@ class Chemical:
                 Hvap=None, **data):
         search_ID = search_ID or ID
         if search_db:
-            try:
-                CAS = CAS_from_any(search_ID)
-            except Exception as Error:
-                search_ID = to_searchable_format(search_ID)
-                try: CAS = CAS_from_any(search_ID)
-                except: raise Error
-            self = cls.new(ID, CAS, eos, phase_ref, **data)
+            metadata = chemical_metadata_from_any(search_ID)
+            data['metadata'] = metadata
+            self = cls.new(ID, metadata.CASs, eos, phase_ref,
+                           **data)
         else:
             self = cls.blank(ID, CAS, phase_ref, **data)
         if phase:
@@ -1131,7 +1128,8 @@ class Chemical:
               Tb=None, Tc=None, Pc=None, Vc=None, omega=None,
               Tt=None, Pt=None, Hf=None, LHV=None, combustion=None,
               HHV=None, Hfus=None, dipole=None,
-              similarity_variable=None, iscyclic_aliphatic=None):
+              similarity_variable=None, iscyclic_aliphatic=None,
+              *, metadata=None):
         """
         Reset all chemical properties.
 
@@ -1146,7 +1144,7 @@ class Chemical:
 
         """
         try:
-            info = pubchem_db.search_CAS(CAS)
+            info = metadata or pubchem_db.search_CAS(CAS)
         except:
             pass            
         else:
