@@ -4,9 +4,9 @@ Created on Wed Nov 27 20:09:05 2019
 
 @author: yoelr
 """
-from fluids.core import g
+from math import pi
 
-__all__ = ('R', 'k', 'g', 'N_A', 'calorie', 'epsilon_0')
+__all__ = ('R', 'k', 'g', 'pi', 'N_A', 'calorie', 'epsilon_0')
 
 
 # Obtained from SciPy 0.19 (2014 CODATA)
@@ -28,4 +28,4 @@ calorie = 4.184
 epsilon_0 = 8.854187817620389e-12
 
 #: Acceleration due to gravity [m/s^2]
-g = g
\ No newline at end of file
+g = 9.80665
\ No newline at end of file
