@@ -77,10 +77,6 @@ class PhaseTHandle(PhaseHandle):
             TDependentModelHandle(var + '.g') if g is None else g,
         )
     
-    def load_data_from(self, data: dict):
-        for i in (self.s, self.l, self.g):
-            if i: i.load_data_from(data)
-    
     def set_value(self, var, value):
         for i in (self.s, self.l, self.g):
             if i: i.set_value(var, value)
@@ -100,7 +96,7 @@ class PhaseTPHandle(PhaseHandle):
             TPDependentModelHandle(var + '.g') if g is None else g,
         )
     
-    load_data_from = PhaseTHandle.load_data_from
+    set_value = PhaseTHandle.set_value
     
     def __call__(self, phase, T, P):
         return getattr(self, phase)(T, P)
