@@ -5,14 +5,14 @@ Created on Mon Sep 30 22:23:44 2019
 @author: yoelr
 """
 from math import log
-from scipy.interpolate import interp1d
 from .functor import TFunctor, TPFunctor, Functor, \
                      display_asfunctor, functor_matching_params, functor_name
-from .units_of_measure import chemical_units_of_measure, definitions, format_plot_units, convert
+from ..units_of_measure import chemical_units_of_measure, definitions, format_plot_units, convert
 from numpy import inf as infinity
 from inspect import signature
-import matplotlib.pyplot as plt
 import numpy as np
+import matplotlib.pyplot as plt
+from scipy.interpolate import interp1d
 
 __all__ = ('thermo_model', 'create_axis_labels', 
            'ThermoModel', 'TDependentModel', 'TPDependentModel', 
