@@ -4,7 +4,6 @@ Created on Mon Sep 30 23:02:53 2019
 
 @author: yoelr
 """
-import matplotlib.pyplot as plt
 from collections import deque
 from numpy import inf as infinity
 from .thermo_model import (ThermoModel,
@@ -13,8 +12,9 @@ from .thermo_model import (ThermoModel,
                            thermo_model,
                            create_axis_labels)
 from ..exceptions import DomainError
-from .units_of_measure import definitions
+from ..units_of_measure import definitions
 from .functor import functor_lookalike
+import matplotlib.pyplot as plt
 
 __all__ = ('ThermoModelHandle',
            'TDependentModelHandle',
