@@ -6,7 +6,7 @@ Created on Mon Apr 16 08:58:41 2018
 @author: Yoel Rene Cortes-Pena
 """
 import numpy as np
-from .unifac_data import DOUFSG, DOUFIP2016, UFIP, UFSG
+from ..properties.unifac import DOUFSG, DOUFIP2016, UFIP, UFSG
 from flexsolve import njitable
 
 __all__ = ('ActivityCoefficients',
