@@ -125,7 +125,7 @@ class Mixture:
         """Solve for temperature in Kelvin."""
         # First approximation
         H_guess = self.H(phase, mol, T_guess, P)
-        if (H - H_guess) < 1e-3: return T_guess
+        if abs(H - H_guess) < 1e-3: return T_guess
         Cn = self.Cn(phase, mol, T_guess)
         T = T_guess + (H - H_guess) / Cn
         if self.rigorous_energy_balance:
@@ -149,7 +149,7 @@ class Mixture:
         # First approximation
         phase_mol = tuple(phase_mol)
         H_guess = self.xH(phase_mol, T_guess, P)
-        if (H - H_guess) < 1e-3: return T_guess
+        if abs(H - H_guess) < 1e-3: return T_guess
         Cn = self.xCn(phase_mol, T_guess)
         T = T_guess + (H - H_guess)/Cn
         if self.rigorous_energy_balance:
