@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 """
 Created on Wed Oct 30 12:07:13 2019
-
 @author: yoelr
 """
 from . import (acentric,
@@ -16,27 +15,40 @@ from . import (acentric,
                heat_capacity,
                identifiers,
                lennard_jones,
-               miscdata,
                permittivity,
                phase_change,
                reaction,
                interface,
                thermal_conductivity,
                triple,
-               utils,
                vapor_pressure,
                virial,
                viscosity,
-               volume)
-
-__all__ = ('combustion', 'electrolyte_conductivity', 'critical', 'dipole',
-           'electrolytes', 'elements', 
-           'eos', 'heat_capacity',  'identifiers', 
-           'lennard_jones', 'miscdata',
-           'permittivity', 'phase_change',  'reaction', 
-           'interface', 'thermal_conductivity', 'triple', 
-           'utils', 'vapor_pressure', 'virial',
-		   'viscosity', 'volume', 'acentric', 
-           'dippr',)
-
+               volume,
+               unifac,
+)
 
+__all__ = ('combustion', 
+           'electrolyte_conductivity', 
+           'critical', 
+           'dipole',
+           'electrolytes', 
+           'elements', 
+           'eos', 
+           'heat_capacity',  
+           'identifiers', 
+           'lennard_jones',
+           'permittivity', 
+           'phase_change',  
+           'reaction', 
+           'interface', 
+           'thermal_conductivity', 
+           'triple', 
+           'vapor_pressure', 
+           'virial',
+		   'viscosity', 
+           'volume', 
+           'acentric', 
+           'dippr',
+           'unifac',
+)
