@@ -36,7 +36,9 @@ __all__ = ('compute_acentric_factor',
 from math import log, log10
 from .critical import (critical_point_temperature,
                        critical_point_pressure)
-from .critical import critical_data_PSRKR4, critical_data_PassutDanner, critical_data_Yaws
+from .data import (critical_data_PSRKR4, 
+                   critical_data_PassutDanner, 
+                   critical_data_Yaws)
 from .phase_change import normal_boiling_point_temperature
 from .vapor_pressure import vapor_pressure_handle
 
