@@ -96,42 +96,16 @@ References
 """
 
 from collections import namedtuple
-from .utils import CASDataReader, get_from_data_sources
+from .data import critical_data_sources, get_from_data_sources
 from .._constants import N_A
 
 __all__ = ('critical_point_temperature',
            'critical_point_pressure',
            'critical_point_volume',
            'Mersmann_Kind_predictor',
-           'Ihmels', 'Meissner', 'Grigoras', 
-           'critical_data_IUPAC', 'critical_data_Matthews',
-           'critical_data_CRC', 'critical_data_PSRKR4',
-           'critical_data_PassutDanner', 'critical_data_Yaws')
-
-### Read the various data files
-# TODO: check out 12E of this data http://pubsdc3.acs.org/doi/10.1021/acs.jced.5b00571
-
-read = CASDataReader(__file__, 'Critical Properties')
-critical_data_IUPAC = read('IUPACOrganicCriticalProps.tsv')  # IUPAC Organic data series
-critical_data_Matthews = read('Mathews1972InorganicCriticalProps.tsv')
-critical_data_CRC = read('CRCCriticalOrganics.tsv') # CRC Handbook from TRC Organic data section (only in 2015)
-critical_data_PSRKR4 = read('Appendix to PSRK Revision 4.tsv')
-critical_data_PassutDanner = read('PassutDanner1973.tsv')
-critical_data_Yaws = read('Yaws Collection.tsv')
+           'Ihmels', 'Meissner', 'Grigoras',)
  
 
-# %% Retrievers
-
-critical_data_sources = {
-    'IUPAC': critical_data_IUPAC,
-    'Matthews': critical_data_Matthews,
-    'CRC': critical_data_CRC,
-    'PSRK': critical_data_PSRKR4,
-    'Passut Danner':critical_data_PassutDanner,
-    'Yaws': critical_data_Yaws,
-}
-
-
 # %%
 
 CriticalPoint = namedtuple('CriticalPoint', ('Tc', 'Pc', 'Vc'), module=__file__)
