@@ -4,8 +4,7 @@ All data and methods for estimating a chemical's refractivity.
 """
 import os
 import pandas as pd
-from math import pi
-from .._constants import N_A
+from .._constants import N_A, pi
 
 __all__ = ['CRC_RI_organic', 'RI_methods', 'refractive_index', 
            'polarizability_from_RI', 'molar_refractivity_from_RI', 
