@@ -36,19 +36,15 @@ References
 """
 from ..base import functor, TDependentHandleBuilder
 from .dippr import DIPPR_EQ101
-from .utils import CASDataReader
 from math import log, exp
 import numpy as np
-
-# %% Data
-
-read = CASDataReader(__file__, 'Vapor Pressure')
-_WagnerMcGarry = read("Wagner Original McGarry.tsv")
-_Wagner = read("Wagner Collection Poling.tsv")
-_Antoine = read("Antoine Collection Poling.tsv")
-_AntoineExtended = read("Antoine Extended Collection Poling.tsv")
-_Perrys2_8 = read("Table 2-8 Vapor Pressure of Inorganic and Organic Liquids.tsv")
-_VDI_PPDS_3 = read("VDI PPDS Boiling temperatures at different pressures.tsv")
+from .data import (Psat_data_WagnerMcGarry,
+                   Psat_data_Wagner,
+                   Psat_data_Antoine,
+                   Psat_data_AntoineExtended,
+                   Psat_data_Perrys2_8,
+                   Psat_data_VDI_PPDS_3,
+)
 
 # %% Vapor pressure
 
@@ -516,31 +512,31 @@ def Edalat(T, Tc, Pc, ω):
 @TDependentHandleBuilder('Psat')
 def vapor_pressure_handle(handle, CAS, Tb, Tc, Pc, omega):
     add_model = handle.add_model
-    if CAS in _WagnerMcGarry:
-        _, a, b, c, d, Pc, Tc, Tmin = _WagnerMcGarry[CAS]
+    if CAS in Psat_data_WagnerMcGarry:
+        _, a, b, c, d, Pc, Tc, Tmin = Psat_data_WagnerMcGarry[CAS]
         Tmax = Tc
         data = (Tc, Pc, a, b, c, d)
         add_model(Wagner_McGraw.from_args(data), Tmin, Tmax)
-    elif CAS in _Wagner:
-        _, a, b, c, d, Tc, Pc, Tmin, Tmax = _Wagner[CAS]
+    elif CAS in Psat_data_Wagner:
+        _, a, b, c, d, Tc, Pc, Tmin, Tmax = Psat_data_Wagner[CAS]
         # Some Tmin values are missing; Arbitrary choice of 0.1 lower limit
         if np.isnan(Tmin): Tmin = Tmax * 0.1
         data = (Tc, Pc, a, b, c, d)
         add_model(Wagner_McGraw.from_args(data), Tmin, Tmax)
-    if CAS in _AntoineExtended:
-        _, a, b, c, Tc, to, n, e, f, Tmin, Tmax = _AntoineExtended[CAS]
+    if CAS in Psat_data_AntoineExtended:
+        _, a, b, c, Tc, to, n, e, f, Tmin, Tmax = Psat_data_AntoineExtended[CAS]
         data = (a, b, c, Tc, to, n, e, f)
         add_model(TRC_Extended_Antoine.from_args(data), Tmin, Tmax)
-    if CAS in _Antoine:
-        _, a, b, c, Tmin, Tmax = _Antoine[CAS]
+    if CAS in Psat_data_Antoine:
+        _, a, b, c, Tmin, Tmax = Psat_data_Antoine[CAS]
         data = (a, b, c)
         add_model(Antoine.from_args(data), Tmin, Tmax)
-    if CAS in _Perrys2_8:
-        _, C1, C2, C3, C4, C5, Tmin, Tmax = _Perrys2_8[CAS]
+    if CAS in Psat_data_Perrys2_8:
+        _, C1, C2, C3, C4, C5, Tmin, Tmax = Psat_data_Perrys2_8[CAS]
         data = (C1, C2, C3, C4, C5)
         add_model(DIPPR_EQ101.from_args(data), Tmin, Tmax)
-    if CAS in _VDI_PPDS_3:
-        _, Tm, Tc, Pc, a, b, c, d = _VDI_PPDS_3[CAS]
+    if CAS in Psat_data_VDI_PPDS_3:
+        _, Tm, Tc, Pc, a, b, c, d = Psat_data_VDI_PPDS_3[CAS]
         data = (Tc, Pc, a, b, c, d)
         add_model(Wagner.from_args(data), 0., Tc,)
     data = (Tb, Tc, Pc)
