@@ -31,14 +31,22 @@ References
 
 """
 from math import exp
-from .utils import CASDataReader
 from ..functional import horner_polynomial
 from ..base import (InterpolatedTDependentModel, 
                     TPDependentHandleBuilder, 
                     TDependentModel, 
                     PhaseTPHandleBuilder,
                     functor)
-from .miscdata import VDI_saturation_dict, VDI_tabular_data
+from .data import (VDI_saturation_dict,
+                   VDI_tabular_data,
+                   mu_data_Dutt_Prasad,
+                   mu_data_VN3,
+                   mu_data_VN2,
+                   mu_data_Perrys2_313,
+                   mu_data_Perrys2_312,
+                   mu_data_VDI_PPDS_7,
+                   mu_data_VDI_PPDS_8,
+)
 # from .electrochem import _Laliberte_Viscosity_ParametersDict, Laliberte_viscosity
 from .dippr import DIPPR_EQ101, DIPPR_EQ102
 
@@ -55,15 +63,6 @@ __all__= ('viscosity_gas_handle',
           'Gharagheizi_gas_viscosity',
 )
 
-read = CASDataReader(__file__, 'Viscosity')
-_Dutt_Prasad = read('Dutt Prasad 3 term.tsv')
-_VN3 = read('Viswanath Natarajan Dynamic 3 term.tsv')
-_VN2 = read('Viswanath Natarajan Dynamic 2 term.tsv')
-_VN2E_data = read('Viswanath Natarajan Dynamic 2 term Exponential.tsv')
-_Perrys2_313 = read('Table 2-313 Viscosity of Inorganic and Organic Liquids.tsv')
-_Perrys2_312 = read('Table 2-312 Vapor Viscosity of Inorganic and Organic Substances.tsv')
-_VDI_PPDS_7 = read('VDI PPDS Dynamic viscosity of saturated liquids polynomials.tsv')
-_VDI_PPDS_8 = read('VDI PPDS Dynamic viscosity of gases polynomials.tsv')
 
 @functor(var='mu.l')
 def Viswanath_Natarajan2(T, a, b):
@@ -310,24 +309,24 @@ def viscosity_liquid_handle(handle, CAS, MW, Tm, Tc, Pc, Vc, omega, Psat, Vl):
         model = InterpolatedTDependentModel(Ts, Ys, Ts[0], Ts[-1], 
                                             name='VDI-interpolated')
         add_model(model)
-    if CAS in _Dutt_Prasad:
-        _, A, B, C, Tmin, Tmax = _Dutt_Prasad[CAS]
+    if CAS in mu_data_Dutt_Prasad:
+        _, A, B, C, Tmin, Tmax = mu_data_Dutt_Prasad[CAS]
         data = (A, B, C)
         add_model(Viswanath_Natarajan3.from_args(data), Tmin, Tmax)
-    if CAS in _VN3:
-        _, _, A, B, C, Tmin, Tmax = _VN3[CAS]
+    if CAS in mu_data_VN3:
+        _, _, A, B, C, Tmin, Tmax = mu_data_VN3[CAS]
         data = (A, B, C)
         add_model(Viswanath_Natarajan3.from_args(data), Tmin, Tmax)
-    if CAS in _VN2:
-        _, _, A, B, Tmin, Tmax = _VN2[CAS]
+    if CAS in mu_data_VN2:
+        _, _, A, B, Tmin, Tmax = mu_data_VN2[CAS]
         data = (A, B)
         add_model(Viswanath_Natarajan2.from_args(data), Tmin ,Tmax)
-    if CAS in _Perrys2_313:
-        _, C1, C2, C3, C4, C5, Tmin, Tmax = _Perrys2_313[CAS]
+    if CAS in mu_data_Perrys2_313:
+        _, C1, C2, C3, C4, C5, Tmin, Tmax = mu_data_Perrys2_313[CAS]
         data = (C1, C2, C3, C4, C5)
         add_model(DIPPR_EQ101.from_args(data), Tmin, Tmax)
-    if CAS in _VDI_PPDS_7:
-        coef = _VDI_PPDS_7[CAS][2:]
+    if CAS in mu_data_VDI_PPDS_7:
+        coef = mu_data_VDI_PPDS_7[CAS][2:]
         add_model(VDI.from_args(coef))
     data = (MW, Tc, Pc, omega)
     if all(data):
@@ -576,12 +575,12 @@ def viscosity_gas_handle(handle, CAS, MW, Tc, Pc, Zc, dipole):
         model = InterpolatedTDependentModel(Ts, Ys, Tmin, Tmax,
                                             name='VDI-interpolated')
         add_model(model)
-    if CAS in _Perrys2_312:
-        _, C1, C2, C3, C4, Tmin, Tmax = _Perrys2_312[CAS]
+    if CAS in mu_data_Perrys2_312:
+        _, C1, C2, C3, C4, Tmin, Tmax = mu_data_Perrys2_312[CAS]
         data = (C1, C2, C3, C4)
         add_model(DIPPR_EQ102.from_args(data), Tmin, Tmax)
-    if CAS in _VDI_PPDS_8:
-        data = _VDI_PPDS_8[CAS].tolist()[1:]
+    if CAS in mu_data_VDI_PPDS_8:
+        data = mu_data_VDI_PPDS_8[CAS].tolist()[1:]
         data.reverse()
         add_model(horner_polynomial.from_kwargs({'coeffs':data}),
                   name='VDI-PPDS')
@@ -602,5 +601,5 @@ def viscosity_gas_handle(handle, CAS, MW, Tc, Pc, Zc, dipole):
         # same as STIEL_THODOS
 
 viscosity_handle = PhaseTPHandleBuilder('mu', None,
-                                          viscosity_liquid_handle,
-                                          viscosity_gas_handle)
+                                        viscosity_liquid_handle,
+                                        viscosity_gas_handle)
