@@ -48,15 +48,23 @@ import numpy as np
 from scipy.interpolate import interp1d
 from math import log, exp
 from .. import functional as fn
-from .utils import CASDataReader
 from .._constants import R
 from .virial import BVirial_Pitzer_Curl, BVirial_Abbott, BVirial_Tsonopoulos, BVirial_Tsonopoulos_extended
-from .miscdata import VDI_saturation_dict, VDI_tabular_data
 from .dippr import DIPPR_EQ105
 # from .electrochem import _Laliberte_Density_ParametersDict, Laliberte_Density
 from ..base import (functor, InterpolatedTDependentModel, 
                     TPDependentModel, TPDependentHandleBuilder,
                     PhaseTPHandleBuilder, ThermoModelHandle)
+from .data import (VDI_saturation_dict,
+                   VDI_tabular_data,
+                   V_data_COSTALD,
+                   V_data_SNM0,
+                   V_data_Perry_l,
+                   V_data_VDI_PPDS_2,
+                   V_data_CRC_inorg_l,
+                   V_data_CRC_inorg_l_const,
+                   V_data_CRC_inorg_s_const,
+                   V_data_CRC_virial)
 
 __all__ = ('volume_handle',
            'Yen_Woods',
@@ -78,16 +86,6 @@ __all__ = ('volume_handle',
            'CRCVirial',
            'Goodman')
 
-read = CASDataReader(__file__, "Density")
-_COSTALD = read('COSTALD Parameters.tsv')
-_SNM0 = read('Mchaweh SN0 deltas.tsv')
-_Perry_l = read('Perry Parameters 105.tsv')
-_VDI_PPDS_2 = read('VDI PPDS Density of Saturated Liquids.tsv')
-_CRC_inorg_l = read('CRC Inorganics densties of molten compounds and salts.tsv')
-_CRC_inorg_l_const = read('CRC Liquid Inorganic Constant Densities.tsv')
-_CRC_inorg_s_const = read('CRC Solid Inorganic Constant Densities.tsv')
-_CRC_virial = read('CRC Virial polynomials.tsv')
-
 # %% Liquids
 
 @functor(var='V.l')
@@ -670,12 +668,12 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
     Tmax = 1000
     all_ = all
     add_model = handle.add_model
-    if CAS in _VDI_PPDS_2:
-        _, MW, Tc_, rhoc, A, B, C, D = _VDI_PPDS_2[CAS]
+    if CAS in V_data_VDI_PPDS_2:
+        _, MW, Tc_, rhoc, A, B, C, D = V_data_VDI_PPDS_2[CAS]
         data = (Tc, rhoc, MW, A, B, C, D)
         add_model(VDI_PPDS.from_args(data), 0., Tc_)
-    if CAS in _Perry_l:
-        _, C1, C2, C3, C4, Tmin, Tmax = _Perry_l[CAS]
+    if CAS in V_data_Perry_l:
+        _, C1, C2, C3, C4, Tmin, Tmax = V_data_Perry_l[CAS]
         data = (C1, C2, C3, C4, True)
         add_model(DIPPR_EQ105.from_args(data), Tmin, Tmax)
     if CAS in VDI_saturation_dict:
@@ -686,8 +684,8 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
     data = (Tb, Tc, Pc, MW, dipole, has_hydroxyl)
     if all_([i is not None for i in data]):
         add_model(Campbell_Thodos.from_args(data), 0, Tc)
-    if CAS in _CRC_inorg_l:
-        _, MW, rho, k, Tm, Tmax = _CRC_inorg_l[CAS]
+    if CAS in V_data_CRC_inorg_l:
+        _, MW, rho, k, Tm, Tmax = V_data_CRC_inorg_l[CAS]
         data = (MW, rho, k, Tm)
         add_model(CRC_Inorganic.from_args(data), Tm, Tmax)
     data = (Tc, Vc, Zc)
@@ -703,21 +701,21 @@ def volume_liquid_handle(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc,
     data = (Tc, Vc, omega)
     if all_(data):
         add_model(Townsend_Hales.from_args(data), 0, Tc)
-        if CAS in _SNM0:
-            SNM0_delta_SRK = float(_SNM0.at[CAS, 'delta_SRK'])
+        if CAS in V_data_SNM0:
+            SNM0_delta_SRK = float(V_data_SNM0.at[CAS, 'delta_SRK'])
             data = (Tc, Vc, omega, SNM0_delta_SRK)
             add_model(SNM0.from_args(data))
-    if CAS in _CRC_inorg_l_const:
-        Vl = float(_CRC_inorg_l_const.at[CAS, 'Vm'])
+    if CAS in V_data_CRC_inorg_l_const:
+        Vl = float(V_data_CRC_inorg_l_const.at[CAS, 'Vm'])
         add_model(Vl, Tmin, Tmax, name="CRC inorganic liquid constant")
-    if Tc and Pc and CAS in _COSTALD:
-        Zc_ = _COSTALD.at[CAS, 'Z_RA']
+    if Tc and Pc and CAS in V_data_COSTALD:
+        Zc_ = V_data_COSTALD.at[CAS, 'Z_RA']
         if not np.isnan(Zc_): Zc_ = float(Zc_)
         data = (Tc, Pc, Zc_)
         add_model(Rackett.from_args(data), Tmin, Tmax)
         # Roughly data at STP; not guaranteed however; not used for Trange
     data = (Tc, Vc, omega)
-    if all_(data) and CAS in _COSTALD:
+    if all_(data) and CAS in V_data_COSTALD:
         add_model(Costald.from_args(data), 0, Tc)
     data = (Tc, Pc, omega)
     if all_(data):
@@ -766,8 +764,8 @@ def volume_gas_handle(handle, CAS, Tc, Pc, omega, eos):
         add_model(Tsonopoulos.from_args(data))
         add_model(Abbott.from_args(data))
         add_model(Pitzer_Curl.from_args(data))
-    if CAS in _CRC_virial:
-        _, *data = _CRC_virial[CAS]
+    if CAS in V_data_CRC_virial:
+        _, *data = V_data_CRC_virial[CAS]
         add_model(CRCVirial.from_args(data))
     add_model(ideal_gas_model)
 
@@ -812,8 +810,8 @@ def Goodman(T, Tt, V_l):
 
 @TPDependentHandleBuilder('V.s')
 def volume_solid_handle(handle, CAS):
-    if CAS in _CRC_inorg_s_const:
-        CRC_INORG_S_Vm = float(_CRC_inorg_s_const.at[CAS, 'Vm'])
+    if CAS in V_data_CRC_inorg_s_const:
+        CRC_INORG_S_Vm = float(V_data_CRC_inorg_s_const.at[CAS, 'Vm'])
         handle.add_model(CRC_INORG_S_Vm, 0, 1e6, 0, 1e12)
 
 
