@@ -9,3 +9,5 @@ __all__ = (*_reaction.__all__,)
 
 from ._reaction import *
 
+#: Whether or not to check reaction feasibility.
+CHECK_FEASIBILITY = True
\ No newline at end of file
