@@ -5,7 +5,6 @@ Created on Fri Dec 13 08:08:14 2019
 @author: yoelr
 """
 
-from . import name_utils
 from . import pickle_utils
 from . import repr_utils
 from . import decorator_utils
@@ -17,10 +16,8 @@ from . import var_utils
 from . import registry
 from . import colors
 from . import plot_utils
-from . import load_utils
 
-__all__ = (*name_utils.__all__,
-           *pickle_utils.__all__,
+__all__ = (*pickle_utils.__all__,
            *repr_utils.__all__,
            *decorator_utils.__all__,
            *other_utils.__all__,
@@ -31,10 +28,8 @@ __all__ = (*name_utils.__all__,
            *registry.__all__,
            *colors.__all__,
            *plot_utils.__all__,
-           *load_utils.__all__,
 )
 
-from .name_utils import *
 from .pickle_utils import *
 from .repr_utils import *
 from .decorator_utils import *
@@ -45,5 +40,4 @@ from .assert_utils import *
 from .var_utils import *
 from .registry import *
 from .colors import *
-from .plot_utils import *
-from .load_utils import *
\ No newline at end of file
+from .plot_utils import *
\ No newline at end of file
